Struct google_spanner1::GetDatabaseDdlResponse
source · Expand description
The response for GetDatabaseDdl.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- instances databases get ddl projects (response)
Fields
statements: Option<Vec<String>>A list of formatted DDL statements defining the schema of the database specified in the request.