Struct google_spanner1::Instance

source ·
pub struct Instance {
    pub state: Option<String>,
    pub display_name: Option<String>,
    pub name: Option<String>,
    pub node_count: Option<i32>,
    pub labels: Option<HashMap<String, String>>,
    pub config: Option<String>,
}
An isolated set of Cloud Spanner resources on which databases can be hosted.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

state: Option<String>

Output only. The current instance state. For CreateInstance, the state must be either omitted or set to CREATING. For UpdateInstance, the state must be either omitted or set to READY.

display_name: Option<String>

Required. The descriptive name for this instance as it appears in UIs. Must be unique per project and between 4 and 30 characters in length.

name: Option<String>

Required. A unique identifier for the instance, which cannot be changed after the instance is created. Values are of the form projects/<project>/instances/a-z*[a-z0-9]. The final segment of the name must be between 6 and 30 characters in length.

node_count: Option<i32>

Required. The number of nodes allocated to this instance. This may be zero in API responses for instances that are not yet in state READY.

See the documentation for more information about nodes.

labels: Option<HashMap<String, String>>

Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer’s organizational needs and deployment strategies. Cloud Labels can be used to filter collections of resources. They can be used to control how resource metrics are aggregated. And they can be used as arguments to policy management rules (e.g. route, firewall, load balancing, etc.).

  • Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?.
  • Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?.
  • No more than 64 labels can be associated with a given resource.

See https://goo.gl/xmQnxf for more information on and examples of labels.

If you plan to use labels in your own code, please note that additional characters may be allowed in the future. And so you are advised to use an internal label representation, such as JSON, which doesn’t rely upon specific characters being disallowed. For example, representing labels as the string: name + “” + value would prove problematic if we were to allow “” in a future release.

config: Option<String>

Required. The name of the instance’s configuration. Values are of the form projects/<project>/instanceConfigs/<configuration>. See also InstanceConfig and ListInstanceConfigs.