pub struct InstanceConfig {
    pub display_name: Option<String>,
    pub name: Option<String>,
}
A possible configuration for a Cloud Spanner instance. Configurations define the geographic placement of nodes and their replication.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

display_name: Option<String>

The name of this instance configuration as it appears in UIs.

name: Option<String>

A unique identifier for the instance configuration. Values are of the form projects/<project>/instanceConfigs/a-z*