pub struct ListInstanceConfigsResponse {
pub next_page_token: Option<String>,
pub instance_configs: Option<Vec<InstanceConfig>>,
}Expand description
The response for ListInstanceConfigs.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- instance configs list projects (response)
Fields
next_page_token: Option<String>next_page_token can be sent in a subsequent
ListInstanceConfigs call to
fetch more of the matching instance configurations.
instance_configs: Option<Vec<InstanceConfig>>The list of requested instance configurations.