Struct google_spanner1::PartialResultSet
source · pub struct PartialResultSet {
pub chunked_value: Option<bool>,
pub resume_token: Option<String>,
pub values: Option<Vec<String>>,
pub metadata: Option<ResultSetMetadata>,
pub stats: Option<ResultSetStats>,
}Expand description
Partial results from a streaming read or SQL query. Streaming reads and SQL queries better tolerate large result sets, large rows, and large values, but are a little trickier to consume.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
chunked_value: Option<bool>If true, then the final value in values is chunked, and must
be combined with more values from subsequent PartialResultSets
to obtain a complete field value.
resume_token: Option<String>Streaming calls might be interrupted for a variety of reasons, such
as TCP connection loss. If this occurs, the stream of results can
be resumed by re-sending the original request and including
resume_token. Note that executing any other transaction in the
same session invalidates the token.
values: Option<Vec<String>>A streamed result set consists of a stream of values, which might
be split into many PartialResultSet messages to accommodate
large rows and/or large values. Every N complete values defines a
row, where N is equal to the number of entries in
metadata.row_type.fields.
Most values are encoded based on type as described here.
It is possible that the last value in values is “chunked”,
meaning that the rest of the value is sent in subsequent
PartialResultSet(s). This is denoted by the chunked_value
field. Two or more chunked values can be merged to form a
complete value as follows:
bool/number/null: cannot be chunkedstring: concatenate the stringslist: concatenate the lists. If the last element in a list is astring,list, orobject, merge it with the first element in the next list by applying these rules recursively.object: concatenate the (field name, field value) pairs. If a field name is duplicated, then apply these rules recursively to merge the field values.
Some examples of merging:
"foo", "bar" => "foobar"
[2, 3], [4] => [2, 3, 4]
["a", "b"], ["c", "d"] => ["a", "bc", "d"]
["a", ["b", "c"]], [["d"], "e"] => ["a", ["b", "cd"], "e"]
{"a": "1"}, {"b": "2"} => {"a": "1", "b": 2"}
{"a": "1"}, {"a": "2"} => {"a": "12"}
{"a": ["1"]}, {"a": ["2"]} => {"a": ["12"]}For a more complete example, suppose a streaming SQL query is
yielding a result set whose rows contain a single string
field. The following PartialResultSets might be yielded:
{
"metadata": { ... }
"values": ["Hello", "W"]
"chunked_value": true
"resume_token": "Af65..."
}
{
"values": ["orl"]
"chunked_value": true
"resume_token": "Bqp2..."
}
{
"values": ["d"]
"resume_token": "Zx1B..."
}This sequence of PartialResultSets encodes two rows, one
containing the field value "Hello", and a second containing the
field value "World" = "W" + "orl" + "d".
metadata: Option<ResultSetMetadata>Metadata about the result set, such as row type information. Only present in the first response.
stats: Option<ResultSetStats>Query plan and execution statistics for the statement that produced this streaming result set. These can be requested by setting ExecuteSqlRequest.query_mode and are sent only once with the last response in the stream. This field will also be present in the last response for DML statements.