Struct google_spanner1::PlanNode
source · pub struct PlanNode {
pub index: Option<i32>,
pub kind: Option<String>,
pub display_name: Option<String>,
pub execution_stats: Option<HashMap<String, String>>,
pub child_links: Option<Vec<ChildLink>>,
pub short_representation: Option<ShortRepresentation>,
pub metadata: Option<HashMap<String, String>>,
}Expand description
Node information for nodes appearing in a QueryPlan.plan_nodes.
This type is not used in any activity, and only used as part of another schema.
Fields
index: Option<i32>The PlanNode’s index in node list.
kind: Option<String>Used to determine the type of node. May be needed for visualizing different kinds of nodes differently. For example, If the node is a SCALAR node, it will have a condensed representation which can be used to directly embed a description of the node in its parent.
display_name: Option<String>The display name for the node.
execution_stats: Option<HashMap<String, String>>The execution statistics associated with the node, contained in a group of key-value pairs. Only present if the plan was returned as a result of a profile query. For example, number of executions, number of rows/time per execution etc.
child_links: Option<Vec<ChildLink>>List of child node indexes and their relationship to this parent.
short_representation: Option<ShortRepresentation>Condensed representation for SCALAR nodes.
metadata: Option<HashMap<String, String>>Attributes relevant to the node contained in a group of key-value pairs. For example, a Parameter Reference node could have the following information in its metadata:
{
"parameter_reference": "param1",
"parameter_type": "array"
}Trait Implementations
sourceimpl<'de> Deserialize<'de> for PlanNode
impl<'de> Deserialize<'de> for PlanNode
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Part for PlanNode