Struct google_spanner1::ResultSet
source · pub struct ResultSet {
pub rows: Option<Vec<Vec<String>>>,
pub stats: Option<ResultSetStats>,
pub metadata: Option<ResultSetMetadata>,
}Expand description
Results from Read or ExecuteSql.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- instances databases sessions execute sql projects (response)
- instances databases sessions read projects (response)
Fields
rows: Option<Vec<Vec<String>>>Each element in rows is a row whose format is defined by
metadata.row_type. The ith element
in each row matches the ith field in
metadata.row_type. Elements are
encoded based on type as described
here.
stats: Option<ResultSetStats>Query plan and execution statistics for the SQL statement that produced this result set. These can be requested by setting ExecuteSqlRequest.query_mode. DML statements always produce stats containing the number of rows modified, unless executed using the ExecuteSqlRequest.QueryMode.PLAN ExecuteSqlRequest.query_mode. Other fields may or may not be populated, based on the ExecuteSqlRequest.query_mode.
metadata: Option<ResultSetMetadata>Metadata about the result set, such as row type information.