pub struct Session {
    pub labels: Option<HashMap<String, String>>,
    pub create_time: Option<String>,
    pub approximate_last_use_time: Option<String>,
    pub name: Option<String>,
}
A session in the Cloud Spanner API.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

labels: Option<HashMap<String, String>>

The labels for the session.

  • Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?.
  • Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?.
  • No more than 64 labels can be associated with a given session.

See https://goo.gl/xmQnxf for more information on and examples of labels.

create_time: Option<String>

Output only. The timestamp when the session is created.

approximate_last_use_time: Option<String>

Output only. The approximate timestamp when the session is last used. It is typically earlier than the actual last use time.

name: Option<String>

The name of the session. This is always system-assigned; values provided when creating a session are ignored.