Struct google_spanner1::Type
source · pub struct Type {
pub struct_type: Option<StructType>,
pub code: Option<String>,
pub array_element_type: Option<Option<Box<Type>>>,
}Expand description
Type indicates the type of a Cloud Spanner value, as might be stored in a
table cell or returned from an SQL query.
This type is not used in any activity, and only used as part of another schema.
Fields
struct_type: Option<StructType>If code == STRUCT, then struct_type
provides type information for the struct’s fields.
code: Option<String>Required. The TypeCode for this type.
array_element_type: Option<Option<Box<Type>>>If code == ARRAY, then array_element_type
is the type of the array elements.