Struct google_spanner1::Write
source · pub struct Write {
pub table: Option<String>,
pub values: Option<Vec<Vec<String>>>,
pub columns: Option<Vec<String>>,
}Expand description
Arguments to insert, update, insert_or_update, and replace operations.
This type is not used in any activity, and only used as part of another schema.
Fields
table: Option<String>Required. The table whose rows will be written.
values: Option<Vec<Vec<String>>>The values to be written. values can contain more than one
list of values. If it does, then multiple rows are written, one
for each entry in values. Each list in values must have
exactly as many entries as there are entries in columns
above. Sending multiple lists is equivalent to sending multiple
Mutations, each containing one values entry and repeating
table and columns. Individual values in each list are
encoded as described here.
columns: Option<Vec<String>>The names of the columns in table to be written.
The list of columns must contain enough columns to allow Cloud Spanner to derive values for all primary key columns in the row(s) to be modified.