Struct google_spanner1::Expr
source · pub struct Expr {
pub title: Option<String>,
pub expression: Option<String>,
pub description: Option<String>,
pub location: Option<String>,
}Expand description
Represents an expression text. Example:
title: "User account presence"
description: "Determines whether the request has a user account"
expression: "size(request.user) > 0"This type is not used in any activity, and only used as part of another schema.
Fields
title: Option<String>An optional title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
expression: Option<String>Textual representation of an expression in Common Expression Language syntax.
The application context of the containing message determines which well-known feature set of CEL is supported.
description: Option<String>An optional description of the expression. This is a longer text which describes the expression, e.g. when hovered over it in a UI.
location: Option<String>An optional string indicating the location of the expression for error reporting, e.g. a file name and a position in the file.