Struct google_spanner1::PartitionReadRequest
source · pub struct PartitionReadRequest {
pub index: Option<String>,
pub transaction: Option<TransactionSelector>,
pub key_set: Option<KeySet>,
pub partition_options: Option<PartitionOptions>,
pub table: Option<String>,
pub columns: Option<Vec<String>>,
}Expand description
The request for PartitionRead
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
index: Option<String>If non-empty, the name of an index on table. This index is used instead of the table primary key when interpreting key_set and sorting result rows. See key_set for further information.
transaction: Option<TransactionSelector>Read only snapshot transactions are supported, read/write and single use transactions are not.
key_set: Option<KeySet>Required. key_set identifies the rows to be yielded. key_set names the
primary keys of the rows in table to be yielded, unless index
is present. If index is present, then key_set instead names
index keys in index.
It is not an error for the key_set to name rows that do not
exist in the database. Read yields nothing for nonexistent rows.
partition_options: Option<PartitionOptions>Additional options that affect how many partitions are created.
table: Option<String>Required. The name of the table in the database to be read.
columns: Option<Vec<String>>The columns of table to be returned for each row matching this request.