Struct google_spanner1::SetIamPolicyRequest
source · Expand description
Request message for SetIamPolicy method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- instances databases set iam policy projects (request)
- instances set iam policy projects (request)
Fields
policy: Option<Policy>REQUIRED: The complete policy to be applied to the resource. The size of
the policy is limited to a few 10s of KB. An empty policy is a
valid policy but certain Cloud Platform services (such as Projects)
might reject them.