Struct google_spanner1::UpdateInstanceRequest
source · pub struct UpdateInstanceRequest {
pub instance: Option<Instance>,
pub field_mask: Option<String>,
}Expand description
The request for UpdateInstance.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- instances patch projects (request)
Fields
instance: Option<Instance>Required. The instance to update, which must always include the instance name. Otherwise, only fields mentioned in [][google.spanner.admin.instance.v1.UpdateInstanceRequest.field_mask] need be included.
field_mask: Option<String>Required. A mask specifying which fields in [][google.spanner.admin.instance.v1.UpdateInstanceRequest.instance] should be updated. The field mask must always be specified; this prevents any future fields in [][google.spanner.admin.instance.v1.Instance] from being erased accidentally by clients that do not know about them.